@@ -157,14 +157,31 @@
 #' stochastic gradient descent. arXiv preprint arXiv:1107.2490, 2011.
 #'
 #' @examples
-#' ## Dobson (1990, p.93): Randomized Controlled Trial
-#' counts <- c(18, 17, 15, 20, 10, 20, 25, 13, 12)
-#' outcome <- gl(3, 1, 9)
-#' treatment <- gl(3, 3)
-#' print(d.AD <- data.frame(treatment, outcome, counts))
-#' sgd.D93 <- sgd(counts ~ outcome + treatment, model="glm",
-#'                model.control=list(family = poisson()))
-#' sgd.D93
+#' ## Linear regression
+#' set.seed(42)
+#' N <- 1e4
+#' d <- 10
+#' X <- matrix(rnorm(N*d), ncol=d)
+#' theta <- rep(5, d+1)
+#' eps <- rnorm(N)
+#' y <- cbind(1, X) %*% theta + eps
+#' dat <- data.frame(y=y, x=X)
+#' sgd.theta <- sgd(y ~ ., data=dat, model="lm")
+#' sprintf("Mean squared error: %0.3f", mean((theta - as.numeric(sgd.theta$coefficients))^2))
+#'
+#' ## Wine quality (Cortez et al., 2009): Logistic regression
+#' set.seed(42)
+#' data("winequality")
+#' dat <- winequality
+#' dat$quality <- as.numeric(dat$quality > 5) # transform to binary
+#' test.set <- sample(1:nrow(dat), size=nrow(dat)/8, replace=FALSE)
+#' dat.test <- dat[test.set, ]
+#' dat <- dat[-test.set, ]
+#' sgd.theta <- sgd(quality ~ ., data=dat,
+#'                model="glm", model.control=binomial(link="logit"),
+#'                sgd.control=list(reltol=1e-5, npasses=200),
+#'                  lr.control=c(scale=1, gamma=1, alpha=30, c=1))
+#' sgd.theta
 #'
 #' @useDynLib sgd
 #' @import MASS
@@ -296,6 +313,16 @@ fit <- function(x, y, model,
     }
   }
 
+  if (model %in% c("lm", "glm")) {
+    model.control$transfer <- transfer_name(model.control$family$link)
+    family <- model.control$family
+    model.control$family <- family$family
+    # Enable logistic regression if response is binary factor.
+    if (is.factor(y) && family == "binomial") {
+      y <- as.integer(as.character(y))
+    }
+  }
+
   dataset <- list(X=x, Y=as.matrix(y))
   if ('big.matrix' %in% class(x)) {
     dataset$big <- TRUE
@@ -305,12 +332,6 @@ fit <- function(x, y, model,
     dataset[["bigmat"]] <- new("externalptr")
   }
 
-  if (model %in% c("lm", "glm")) {
-    model.control$transfer <- transfer_name(model.control$family$link)
-    family <- model.control$family
-    model.control$family <- family$family
-  }
-
   if (sgd.control$verbose) {
     print("Completed pre-processing attributes...")
     print("Running C++ algorithm...")
